# SIPHoney: a SIP Honeypot

This is a honeypot simulating a SIP server listening to UDP port 5060 (but
not to TCP port 5060, like a real SIP server also would). It borrows some
ideas from the [honeypots](https://github.com/qeeqbox/honeypots) package.
The emulation is not perfect - it just sends an acceptance code (`200 OK`)
for all the requests sent to it.

## Prerequisites

- a working database server (only if you use an output plugin that outputs to
a database - e.g., MySQL)

## Usage

Check the [Linux installation guide](siphoney/data/docs/INSTALL.md) or the
[Windows installation guide](siphoney/data/docs/INSTALLWIN.md) for complete
instructions on how to install, configure, and run the honeypot.
